@@ -27,8 +27,15 @@ class Mail(object):
     from_email = None
     from_name = None
     attachments = None
+    cc = None
+    bcc = None
 
-    def __init__(self, subject=None, from_email=None, from_name=None):
+    def __init__(self,
+                 subject=None,
+                 from_email=None,
+                 from_name=None,
+                 cc=None,
+                 bcc=None):
         """Initialize an e-mail.
 
         :param subject: Subject of the e-mail.
@@ -38,6 +45,10 @@ class Mail(object):
         :param from_name:
             Sender's name. If ``None``, defaults to the ``DEFAULT_FROM_NAME``
             setting if available. Default ``None``.
+        :param cc:
+            List of emails this message should be CC'd to
+        :param bcc:
+            List of emails this message should be BCC'd to
         """
 
         if subject:
@@ -50,13 +61,21 @@ class Mail(object):
             self.from_name = from_name
         elif not self.from_name:
             self.from_name = getattr(settings, 'DEFAULT_FROM_NAME', None)
+        if cc:
+            self.cc = cc
+        if bcc:
+            self.bcc = bcc
         self.attachments = {}
 
     def send(self,
              to,
              text_body,
              html_body=None,
-             subject=None):
+             subject=None,
+             tags=None,
+             metadata=None,
+             cc=None,
+             bcc=None):
         """Send the e-mail.
 
         :param to: Recipient of the e-mail.
@@ -64,6 +83,10 @@ class Mail(object):
         :param html_body: Rich HTML e-mail body.
         :param subject:
             Subject. If not provided, the class instance variable will be used.
+        :param tags: list of mandrill tags
+        :param metadata: dict of mandrill metadata
+        :param cc: list of emails this message should be CC'd to
+        :param bcc: list of emails this message should be BCC'd to
         """
 
         from_combined = '%s <%s>' % (
@@ -71,10 +94,15 @@ class Mail(object):
             self.from_email
         ) if self.from_name else self.from_email
 
+        cc = cc if cc is not None else self.cc
+        bcc = bcc if bcc is not None else self.bcc
+
         message = EmailMultiAlternatives(subject or self.subject,
                                          text_body,
                                          from_combined,
-                                         [to])
+                                         [to],
+                                         cc=cc,
+                                         bcc=bcc)
 
         if html_body:
             message.attach_alternative(html_body, "text/html")
@@ -83,6 +111,12 @@ class Mail(object):
         for filename, (data, mime_type) in self.attachments.items():
             message.attach(filename, data, mime_type)
 
+        # Optional Mandrill-specific extensions:
+        if tags:
+            message.tags = tags
+        if metadata:
+            message.metadata = metadata
+
         # Send the message.
         message.send()
 
@@ -133,7 +167,9 @@ class TemplateMail(Mail):
                  context=None,
                  subject=None,
                  from_email=None,
-                 from_name=None):
+                 from_name=None,
+                 cc=None,
+                 bcc=None):
         """Initialize a template based e-mail.
 
         :param subject_template_name:
@@ -151,6 +187,10 @@ class TemplateMail(Mail):
         :param from_name:
             Sender's name. If ``None``, defaults to the ``DEFAULT_FROM_NAME``
             setting if available. Default ``None``.
+        :param cc:
+            List of emails this message should be CC'd to
+        :param bcc:
+            List of emails this message should be BCC'd to
         """
 
         if subject_template_name:
@@ -167,9 +207,17 @@ class TemplateMail(Mail):
 
         super(TemplateMail, self).__init__(subject=subject,
                                            from_email=from_email,
-                                           from_name=from_name)
+                                           from_name=from_name,
+                                           cc=cc,
+                                           bcc=bcc)
 
-    def send(self, to, context={}):
+    def send(self,
+             to,
+             context=None,
+             tags=None,
+             metadata=None,
+             cc=None,
+             bcc=None):
         """Send the e-mail.
 
         :param to: Recipient of the e-mail.
@@ -201,4 +249,13 @@ class TemplateMail(Mail):
             html_body = render_to_string(self.html_template_name,
                                          local_context).strip()
 
-        super(TemplateMail, self).send(to, text_body, html_body, subject)
+        super(TemplateMail, self).send(
+            to=to,
+            text_body=text_body,
+            html_body=html_body,
+            subject=subject,
+            tags=tags,
+            metadata=metadata,
+            cc=cc,
+            bcc=bcc
+        )
